@@ -158,8 +158,8 @@ double DouglasPeuckerMod::DistanceGeo(const GeoPoint &p0,
 double DouglasPeuckerMod::DistanceTime(const unsigned time0,
                                         const unsigned time1,
                                         const unsigned time2) {
-  double out = sqrt(abs(time1 - time0) / max_delta_time * threshold) +
-               sqrt(abs(time2 - time0) / max_delta_time * threshold);
+  double out = sqrt(abs(int(time1 - time0)) / max_delta_time * threshold) +
+               sqrt(abs(int(time2 - time0)) / max_delta_time * threshold);
 
   out = pow(out, 2)/4;
 
