@@ -175,7 +175,7 @@ PyObject* Python::WritePhase(const Phase &phase) {
     "duration", (long)phase.duration,
     "circling_direction", FormatCirclingDirection(phase.circling_direction),
     "alt_diff", (long)phase.alt_diff,
-    "distance", (long)phase.alt_diff,
+    "distance", (long)phase.distance,
     "speed", phase.GetSpeed(),
     "vario", phase.GetVario(),
     "glide_rate", phase.GetGlideRate());
@@ -337,17 +337,20 @@ bool Python::PyTupleToIGCFixEnhanced(PyObject *py_fix, IGCFixEnhanced &fix) {
     return false;
   }
 
-  if (PyNumber_Check(py_gps_alt))
+  if (PyNumber_Check(py_gps_alt)) {
     fix.gps_altitude = PyInt_AsLong(py_gps_alt);
-  else
+    fix.gps_valid = true;
+  } else {
     fix.gps_altitude = 0;
+    fix.gps_valid = false;
+  }
 
   if (PyNumber_Check(py_pressure_alt))
     fix.pressure_altitude = PyInt_AsLong(py_pressure_alt);
   else
-    fix.pressure_altitude = 0;
+    /* fall back to GPS altitude - this is the same behaviour as in IGCFix::Apply() */
+    fix.pressure_altitude = fix.gps_altitude;
 
-  fix.gps_valid = true;
 
   if (PyNumber_Check(py_enl))
     fix.enl = PyInt_AsLong(py_enl);
