@@ -97,6 +97,19 @@ void xcsoar_Flight_dealloc(Pyxcsoar_Flight *self) {
   self->ob_type->tp_free((Pyxcsoar_Flight*)self);
 }
 
+PyObject* xcsoar_Flight_setQNH(Pyxcsoar_Flight *self, PyObject *args) {
+  double qnh;
+
+  if (!PyArg_ParseTuple(args, "d", &qnh)) {
+    PyErr_SetString(PyExc_AttributeError, "Can't parse QNH.");
+    return nullptr;
+  }
+
+  self->flight->SetQNH(qnh);
+
+  Py_RETURN_TRUE;
+}
+
 PyObject* xcsoar_Flight_path(Pyxcsoar_Flight *self, PyObject *args) {
   PyObject *py_begin = NULL,
            *py_end = NULL;
@@ -352,11 +365,22 @@ PyObject* xcsoar_Flight_analyse(Pyxcsoar_Flight *self, PyObject *args, PyObject
     Py_DECREF(py_wind);
   }
 
-  PyObject *py_result = Py_BuildValue("{s:N,s:N,s:N,s:N}",
+  /* write QNH */
+  PyObject *py_qnh;
+
+  if (self->flight->qnh_available) {
+    py_qnh = PyFloat_FromDouble(self->flight->qnh.GetHectoPascal());
+  } else {
+    py_qnh = Py_None;
+    Py_INCREF(Py_None);
+  }
+
+  PyObject *py_result = Py_BuildValue("{s:N,s:N,s:N,s:N,s:N}",
     "contests", py_contests,
     "phases", py_phases,
     "performance", Python::WritePerformanceStats(phase_totals),
-    "wind", py_wind_list);
+    "wind", py_wind_list,
+    "qnh", py_qnh);
 
   return py_result;
 }
@@ -416,7 +440,7 @@ PyObject* xcsoar_Flight_encode(Pyxcsoar_Flight *self, PyObject *args) {
 
     encoded_levels.addUnsignedNumber(replay->Level());
     encoded_times.addSignedNumber(basic.time);
-    encoded_altitude.addSignedNumber(fix.gps_altitude);
+    encoded_altitude.addSignedNumber(self->flight->qnh.PressureAltitudeToQNHAltitude(fix.pressure_altitude));
 
     if (fix.enl >= 0)
         encoded_enl.addSignedNumber(fix.enl);
