@@ -35,6 +35,7 @@ struct Pyxcsoar_Flight {
 static PyObject* xcsoar_Flight_new(PyTypeObject *type, PyObject *args, PyObject *kwargs);
 static void xcsoar_Flight_dealloc(Pyxcsoar_Flight *self);
 
+static PyObject* xcsoar_Flight_setQNH(Pyxcsoar_Flight *self, PyObject *args);
 static PyObject* xcsoar_Flight_path(Pyxcsoar_Flight *self, PyObject *args);
 static PyObject* xcsoar_Flight_times(Pyxcsoar_Flight *self);
 static PyObject* xcsoar_Flight_reduce(Pyxcsoar_Flight *self, PyObject *args, PyObject *kwargs);
@@ -42,6 +43,7 @@ static PyObject* xcsoar_Flight_analyse(Pyxcsoar_Flight *self, PyObject *args, Py
 static PyObject* xcsoar_Flight_encode(Pyxcsoar_Flight *self, PyObject *args);
 
 static PyMethodDef xcsoar_Flight_methods[] = {
+  {"setQNH", (PyCFunction)xcsoar_Flight_setQNH, METH_VARARGS, "Set QNH for the flight (in hPa)."},
   {"path", (PyCFunction)xcsoar_Flight_path, METH_VARARGS, "Get flight as list."},
   {"times", (PyCFunction)xcsoar_Flight_times, METH_VARARGS, "Get takeoff/release/landing times from flight."},
   {"reduce", (PyCFunction)xcsoar_Flight_reduce, METH_VARARGS | METH_KEYWORDS, "Reduce flight."},
