@@ -376,14 +376,16 @@ ComputeDynamics(MoreData &basic, const DerivedInfo &calculated)
   const fixed angle = atan((calculated.turn_rate_heading
       * basic.true_airspeed * fixed_inv_g).Radians());
 
-  basic.attitude.bank_angle = Angle::Radians(angle);
-  basic.attitude.bank_angle_available = true;
+  if (!basic.attitude.bank_angle_available) {
+    basic.attitude.bank_angle = Angle::Radians(angle);
+    basic.attitude.bank_angle_computed = true;
+  }
 
-  if (basic.total_energy_vario_available) {
+  if (!basic.attitude.pitch_angle_available && basic.total_energy_vario_available) {
     // estimate pitch angle (assuming balanced turn)
     basic.attitude.pitch_angle = Angle::FromXY(basic.true_airspeed,
                                                basic.gps_vario - basic.total_energy_vario);
-    basic.attitude.pitch_angle_available = true;
+    basic.attitude.pitch_angle_computed = true;
   }
 
   if (!basic.acceleration.available)
