@@ -26,7 +26,7 @@ Copyright_License {
 #include "Device/Parser.hpp"
 #include "Driver/FLARM/Device.hpp"
 #include "Driver/LX/Internal.hpp"
-#include "Device/Internal.hpp"
+#include "Device/Util/NMEAWriter.hpp"
 #include "Device/Register.hpp"
 #include "Blackboard/DeviceBlackboard.hpp"
 #include "Components.hpp"
@@ -58,6 +58,10 @@ Copyright_License {
 #include "Android/VoltageDevice.hpp"
 #endif
 
+#ifdef __APPLE__
+#include "Apple/InternalSensors.hpp"
+#endif
+
 #include <assert.h>
 
 /**
@@ -97,8 +101,10 @@ DeviceDescriptor::DeviceDescriptor(unsigned _index)
    open_job(NULL),
    port(NULL), monitor(NULL), dispatcher(NULL),
    driver(NULL), device(NULL),
-#ifdef ANDROID
+#if defined(ANDROID) || defined(__APPLE__)
    internal_sensors(NULL),
+#endif
+#ifdef ANDROID
    droidsoar_v2(nullptr),
    nunchuck(nullptr),
    voltage(nullptr),
@@ -143,10 +149,12 @@ DeviceDescriptor::GetState() const
   if (port != nullptr)
     return port->GetState();
 
-#ifdef ANDROID
+#if defined(ANDROID) || defined(__APPLE__)
   if (internal_sensors != nullptr)
     return PortState::READY;
+#endif
 
+#ifdef ANDROID
   if (droidsoar_v2 != nullptr)
     return PortState::READY;
 
@@ -231,7 +239,6 @@ DeviceDescriptor::OpenOnPort(DumpPort *_port, OperationEnvironment &env)
 
   parser.Reset();
   parser.SetReal(_tcscmp(driver->name, _T("Condor")) != 0);
-  parser.SetIgnoreChecksum(config.ignore_checksum);
   if (config.IsDriver(_T("Condor")))
     parser.DisableGeoid();
 
@@ -259,10 +266,11 @@ DeviceDescriptor::OpenOnPort(DumpPort *_port, OperationEnvironment &env)
 bool
 DeviceDescriptor::OpenInternalSensors()
 {
-#ifdef ANDROID
+#if defined(ANDROID) || defined(__APPLE__)
   if (is_simulator())
     return true;
 
+#ifdef ANDROID
   internal_sensors =
       InternalSensors::create(Java::GetEnv(), context, GetIndex());
   if (internal_sensors) {
@@ -270,6 +278,10 @@ DeviceDescriptor::OpenInternalSensors()
     internal_sensors->subscribeToSensor(InternalSensors::TYPE_PRESSURE);
     return true;
   }
+#elif defined(__APPLE__)
+  internal_sensors = InternalSensors::create(GetIndex());
+  return (internal_sensors != nullptr);
+#endif
 #endif
   return false;
 }
@@ -455,10 +467,12 @@ DeviceDescriptor::Close()
 
   CancelAsync();
 
-#ifdef ANDROID
+#if defined(ANDROID) || defined(__APPLE__)
   delete internal_sensors;
-  internal_sensors = NULL;
+  internal_sensors = nullptr;
+#endif
 
+#ifdef ANDROID
   delete droidsoar_v2;
   droidsoar_v2 = nullptr;
 
