@@ -23,7 +23,7 @@ Copyright_License {
 
 #include "Volatile.hpp"
 #include "NMEA/Derived.hpp"
-#include "Device/Internal.hpp"
+#include "Device/Util/NMEAWriter.hpp"
 #include "Operation/Operation.hpp"
 
 #include <stdio.h>
