@@ -53,6 +53,7 @@ Copyright_License {
 #include "Device/Driver/CProbe.hpp"
 #include "Device/Driver/LevilAHRS_G.hpp"
 #include "Device/Driver/BlueFlyVario.hpp"
+#include "Device/Driver/OpenVario.hpp"
 #include "Util/Macros.hpp"
 
 #include <assert.h>
@@ -91,6 +92,7 @@ static const struct DeviceRegister *const driver_list[] = {
   &eye_driver,
   &bluefly_driver,
   &cai_lnav_driver,
+  &open_vario_driver,
   NULL
 };
 
