@@ -130,7 +130,7 @@ devStartup()
   }
 
   if (none_available) {
-#ifdef ANDROID
+#if defined(ANDROID) || defined(__APPLE__)
     /* fall back to built-in GPS when no configured device is
        available on this platform */
     LogFormat("Falling back to built-in GPS");
@@ -148,17 +148,17 @@ devStartup()
 void
 VarioWriteNMEA(const TCHAR *text, OperationEnvironment &env)
 {
-  for (unsigned i = 0; i < NUMDEV; i++)
-    if (device_list[i]->IsVega())
-      device_list[i]->WriteNMEA(text, env);
+  for (DeviceDescriptor *i : device_list)
+    if (i->IsVega())
+      i->WriteNMEA(text, env);
 }
 
 DeviceDescriptor *
 devVarioFindVega()
 {
-  for (unsigned i = 0; i < NUMDEV; i++)
-    if (device_list[i]->IsVega())
-      return device_list[i];
+  for (DeviceDescriptor *i : device_list)
+    if (i->IsVega())
+      return i;
 
   return NULL;
 }
@@ -169,9 +169,8 @@ devShutdown()
   // Stop COM devices
   LogFormat("Stop COM devices");
 
-  for (unsigned i = 0; i < NUMDEV; i++) {
-    device_list[i]->Close();
-  }
+  for (DeviceDescriptor *i : device_list)
+    i->Close();
 }
 
 void
