@@ -24,7 +24,6 @@ Copyright_License {
 #ifndef NAV_DIJKSTRA_HPP
 #define NAV_DIJKSTRA_HPP
 
-#include "Util/NonCopyable.hpp"
 #include "Dijkstra.hpp"
 #include "ScanTaskPoint.hpp"
 #include "SolverResult.hpp"
@@ -41,13 +40,9 @@ Copyright_License {
  *
  * NavDijkstra<SearchPoint>
  */
-class NavDijkstra: 
-  private NonCopyable 
-{
+class NavDijkstra {
 protected:
-  enum {
-    MAX_STAGES = 32,
-  };
+  static constexpr unsigned MAX_STAGES = 32;
 
   struct DijkstraMap {
     struct Hash {
@@ -81,11 +76,11 @@ protected:
   unsigned solution[MAX_STAGES];
 
 protected:
-  /** 
+  /**
    * Constructor
-   * 
+   *
    * @param _num_stages Number of stages in search
-   * 
+   *
    * @return Initialised object
    */
   NavDijkstra(const unsigned _num_stages)
@@ -93,8 +88,10 @@ protected:
     SetStageCount(_num_stages);
   }
 
+  NavDijkstra(const NavDijkstra &) = delete;
+
 protected:
-  /** 
+  /**
    * Set the number of stages to search for, and clear the solution
    * array
    */
@@ -103,20 +100,20 @@ protected:
     num_stages =_num_stages;
   }
 
-  /** 
+  /**
    * Determine whether a finished path is valid
-   * 
+   *
    * @param sp Point to check
-   * 
+   *
    * @return True if this terminal point completes a valid solution
    */
   bool IsFinishSatisfied(const ScanTaskPoint sp) const {
     return true;
   }
 
-  /** 
+  /**
    * Add edges from an origin node
-   * 
+   *
    * @param curNode Origin node to add edges from
    */
   virtual void AddEdges(const ScanTaskPoint curNode) = 0;
@@ -128,11 +125,11 @@ protected:
     return stage_number + 1 == num_stages;
   }
 
-  /** 
+  /**
    * Determine whether a point is terminal (no further edges)
-   * 
+   *
    * @param sp Point to test
-   * 
+   *
    * @return True if point is terminal
    */
   gcc_pure
@@ -151,12 +148,12 @@ protected:
     Link(node, node, value);
   }
 
-  /** 
+  /**
    * Iterate search algorithm
-   * 
+   *
    * @param dijkstra Dijkstra structure to iterate
    * @param max_steps Maximum number of steps to update
-   * 
+   *
    * @return True if algorithm returns a terminal path or no path found
    */
   SolverResult DistanceGeneral(unsigned max_steps = 0 - 1) {
@@ -213,13 +210,13 @@ protected:
     return FindStage(p, 0);
   }
 
-  /** 
+  /**
    * Determine optimal solution by backtracing the Dijkstra tree
-   * 
+   *
    * @param destination Terminal point to query
    */
   void FindSolution(const ScanTaskPoint destination) {
-    ScanTaskPoint p(destination); 
+    ScanTaskPoint p(destination);
     unsigned last_stage_number;
 
     do {
