@@ -35,9 +35,7 @@ class ContainerWindow;
  */
 class MenuBar {
 public:
-  enum {
-    MAX_BUTTONS = 32,
-  };
+  static constexpr unsigned MAX_BUTTONS = 32;
 
 protected:
   class Button : public ButtonWindow {
