@@ -116,10 +116,12 @@ public:
 #endif
 
   /**
-   * Generate the color table.
+   * Fills the color_table array with precomputed colors for 256 height and
+   * 64 illumination levels. This is used to speed up the rendering by
+   * preventing the same color calculations over and over again.
    */
-  void ColorTable(const ColorRamp *color_ramp, bool do_water,
-                  unsigned height_scale, int interp_levels);
+  void PrepareColorTable(const ColorRamp *color_ramp, bool do_water,
+                         unsigned height_scale, int interp_levels);
 
   /**
    * Scan the map and fill the height matrix.
