@@ -27,19 +27,13 @@ Copyright_License {
 
 #include "Math/Point2D.hpp"
 
-typedef int32_t ShapeScalar;
-struct ShapePoint : Point2D<ShapeScalar> {
-  /**
-   * Type to be used by vector math, where a range of
-   * max(ShapeScalar)*max(ShapeScalar) is needed.
-   */
-  typedef float SquareType;
+struct ShapePoint : FloatPoint {
+  ShapePoint() = default;
+
+  template<typename... Args>
+  constexpr ShapePoint(Args&&... args):FloatPoint(args...) {}
 };
 
-static inline unsigned
-manhattan_distance(ShapePoint a, ShapePoint b)
-{
-  return abs(a.x - b.x) + abs(a.y - b.y);
-}
+typedef ShapePoint::scalar_type ShapeScalar;
 
 #endif
