@@ -181,8 +181,10 @@ DBFHandle msDBFOpen(struct zzip_dir *zdir,  const char * pszFilename, const char
     }
   }
   free( pszDBFFilename );
-  if( psDBF->fp == NULL )
+  if( psDBF->fp == NULL ) {
+    free(psDBF);
     return( NULL );
+  }
 
 #ifdef SHAPELIB_DISABLED
   psDBF->bNoHeader = MS_FALSE;
@@ -531,8 +533,8 @@ static const char *msDBFReadAttribute(DBFHandle psDBF, int hEntity, int iField )
 
     nRecordOffset = psDBF->nRecordLength * hEntity + psDBF->nHeaderLength;
 
-    safe_fseek( psDBF->fp, nRecordOffset, 0 );
-    zzip_fread( psDBF->pszCurrentRecord, psDBF->nRecordLength, 1, psDBF->fp );
+    zzip_pread(psDBF->fp, psDBF->pszCurrentRecord, psDBF->nRecordLength,
+               nRecordOffset);
 
     psDBF->nCurrentRecord = hEntity;
   }
