@@ -41,12 +41,14 @@
 #include "Device/Driver/LX/Internal.hpp"
 #include "Device/Driver/ILEC.hpp"
 #include "Device/Driver/IMI.hpp"
+#include "Device/Driver/OpenVario.hpp"
 #include "Device/Driver/PosiGraph.hpp"
 #include "Device/Driver/Vega.hpp"
 #include "Device/Driver/Volkslogger.hpp"
 #include "Device/Driver/Westerboer.hpp"
 #include "Device/Driver/Zander.hpp"
 #include "Device/Driver.hpp"
+#include "Device/RecordedFlight.hpp"
 #include "Device/Parser.hpp"
 #include "Device/device.hpp"
 #include "Device/Port/NullPort.hpp"
@@ -63,6 +65,8 @@
 #include "TestUtil.hpp"
 #include "Units/System.hpp"
 
+#include <memory>
+
 static const DeviceConfig dummy_config = DeviceConfig();
 
 /*
@@ -1163,6 +1167,73 @@ TestVega()
   delete device;
 }
 
+static void
+TestOpenVario()
+{
+  NullPort null;
+  Device *device = open_vario_driver.CreateOnPort(dummy_config, null);
+  ok1(device != NULL);
+
+  NMEAInfo nmea_info;
+  nmea_info.Reset();
+  nmea_info.clock = fixed(1);
+
+  // Empty sentence is handled by device driver
+  ok1(device->ParseNMEA("$POV*49", nmea_info));
+
+  // Checksums are validated
+  ok1(!device->ParseNMEA("$POV*48", nmea_info));
+
+  // TE vario is read
+  ok1(device->ParseNMEA("$POV,E,2.15*14", nmea_info));
+  ok1(nmea_info.total_energy_vario_available);
+  ok1(equals(nmea_info.total_energy_vario, 2.15));
+  nmea_info.Reset();
+
+  // Static pressure is read
+  ok1(device->ParseNMEA("$POV,P,1018.35*39", nmea_info));
+  ok1(nmea_info.static_pressure_available);
+  ok1(equals(nmea_info.static_pressure.GetHectoPascal(), 1018.35));
+  nmea_info.Reset();
+
+  // Dynamic pressure is read
+  ok1(device->ParseNMEA("$POV,Q,23.3*04", nmea_info));
+  ok1(nmea_info.dyn_pressure_available);
+  ok1(equals(nmea_info.dyn_pressure.GetPascal(), 23.3));
+  nmea_info.Reset();
+
+  // Total pressure is read
+  ok1(device->ParseNMEA("$POV,R,1025.17*35", nmea_info));
+  ok1(nmea_info.pitot_pressure_available);
+  ok1(equals(nmea_info.pitot_pressure.GetHectoPascal(), 1025.17));
+  nmea_info.Reset();
+
+  // Multiple pressures are read
+  ok1(device->ParseNMEA("$POV,P,1018.35,Q,23.3,R,1025.17*08", nmea_info));
+  ok1(nmea_info.static_pressure_available);
+  ok1(equals(nmea_info.static_pressure.GetHectoPascal(), 1018.35));
+  ok1(nmea_info.dyn_pressure_available);
+  ok1(equals(nmea_info.dyn_pressure.GetPascal(), 23.3));
+  ok1(nmea_info.pitot_pressure_available);
+  ok1(equals(nmea_info.pitot_pressure.GetHectoPascal(), 1025.17));
+  nmea_info.Reset();
+
+  // Airspeed is read
+  ok1(device->ParseNMEA("$POV,S,123.45*05", nmea_info));
+  ok1(nmea_info.airspeed_available);
+  ok1(nmea_info.airspeed_real);
+  ok1(equals(nmea_info.true_airspeed, 123.45 / 3.6));
+  nmea_info.Reset();
+
+  // Temperature is read
+  ok1(device->ParseNMEA("$POV,T,23.52*35", nmea_info));
+  ok1(nmea_info.temperature_available);
+  ok1(equals(nmea_info.temperature, 23.52 + 273.15));
+  nmea_info.Reset();
+
+  delete device;
+}
+
 static void
 TestWesterboer()
 {
@@ -1364,7 +1435,7 @@ TestFlightList(const struct DeviceRegister &driver)
 
 int main(int argc, char **argv)
 {
-  plan_tests(725);
+  plan_tests(754);
 
   TestGeneric();
   TestTasman();
@@ -1384,6 +1455,7 @@ int main(int argc, char **argv)
   TestLX(condor_driver, true);
   TestLXV7();
   TestILEC();
+  TestOpenVario();
   TestVega();
   TestWesterboer();
   TestZander();
